#!/bin/sh
# Prints to standard output the local IP address from
# which the provided host IP address or name is reachable.
# Keeps mute if no local address routes to the target host.
# 2 arguments expected:
# $1 gives the target host IP address or name,
# $2 gives the ping timeout in s for reachability assessment
# of each local address.

if test "$1" = "localhost" -o "$1" = "127.0.0.1"
then
	echo "network.address=$1"
elif ip route | grep "$1" >/dev/null
then
	network=`ip route | grep "$1" | cut -d' ' -f1`
	echo "network.address=$network"
else
	ip route | grep src | while read line
	do
		network=`echo $line | cut -d' ' -f1`
		address=`echo $line | cut -d' ' -f9`
		if ping -q -I $address -c 1 -W $2 $1 >/dev/null
		then
			echo "network.address=$network"	
			exit 0
		fi
	done
fi
